import JSBI from 'jsbi'
import { ChainId } from '@sushiswap/sdk'

// exports for external consumption
export type BigintIsh = JSBI | bigint | string

// export enum ChainId {
//   MAINNET = 1,
//   ROPSTEN = 3,
//   RINKEBY = 4,
//   GÖRLI = 5,
//   KOVAN = 42,
//   TEST = 31337
// }

export enum Rounding {
  ROUND_DOWN,
  ROUND_HALF_UP,
  ROUND_UP
}

export const ZERO = JSBI.BigInt(0)
export const ONE = JSBI.BigInt(1)
export const TWO = JSBI.BigInt(2)
export const THREE = JSBI.BigInt(3)
export const FIVE = JSBI.BigInt(5)
export const TEN = JSBI.BigInt(10)
export const _100 = JSBI.BigInt(100)
export const _997 = JSBI.BigInt(997)
export const _1000 = JSBI.BigInt(1000)

export enum SolidityType {
  uint8 = 'uint8',
  uint256 = 'uint256'
}

export const SOLIDITY_TYPE_MAXIMA = {
  [SolidityType.uint8]: JSBI.BigInt('0xff'),
  [SolidityType.uint256]: JSBI.BigInt('0xffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffff')
}

export const types = {
  EIP712Domain: [
    { name: "name", type: "string" },
    { name: "chainId", type: "uint256" },
    { name: "verifyingContract", type: "address" }
  ],
  LimitOrder: [
    { name: "maker", type: "address" },
    { name: "tokenIn", type: "address" },
    { name: "tokenOut", type: "address" },
    { name: "amountIn", type: "uint256" },
    { name: "amountOut", type: "uint256" },
    { name: "recipient", type: "address" },
    { name: "startTime", type: "uint256" },
    { name: "endTime", type: "uint256" },
    { name: "stopPrice", type: "uint256" },
    { name: "oracleAddress", type: "address" },
    { name: "oracleData", type: "bytes32" }
  ]
}

export const limitOrderType = "LimitOrder";
export const name = "LimitOrder";
export const contract = "0xa513E6E4b8f2a923D98304ec87F64353C4D5C853";

export const LAMBDA_URL = 'https://7purjswusf.execute-api.us-east-1.amazonaws.com/dev'

// aka StopLimitOrder contract
export const getVerifyingContract = (chainId: ChainId): string => {
  switch (chainId) {
    // case ChainId.MAINNET:
    //   return "";
    // case ChainId.ROPSTEN:
    //   return "";
    // case ChainId.RINKEBY:
    //   return "";
    // case ChainId.GÖRLI:
    //   return "";
    case ChainId.MATIC:
      return "0x0dd184Bec9e43701F76d75D5FFfE246B2DC8d4EA";
    case ChainId.KOVAN:
      return "0xce9365dB1C99897f04B3923C03ba9a5f80E8DB87";
    default:
      return "0xa513E6E4b8f2a923D98304ec87F64353C4D5C853";
  }
}
